@@ -9,10 +9,13 @@
 #include <klibc/compiler.h>
 #include <klibc/seek.h>
 #include <sys/types.h>
-#if defined(__mips__) && !defined(__mips64__)
+#if defined(__mips__) && ! defined(__mips64)
 # include <klibc/archfcntl.h>
 #endif
 #include <linux/fcntl.h>
+#include <bitsize.h>
+
+#if _BITSIZE == 32
 
 /* This is ugly, but "struct flock" has actually been defined with
    a long off_t, so it's really "struct flock64".  It just happens
@@ -35,6 +38,8 @@
 # define F_SETLKW F_SETLKW64
 #endif
 
+#endif /* _BITSIZE == 32 */
+
 /* This is defined here as well as in <unistd.h> */
 #ifndef _KLIBC_IN_OPEN_C
 __extern int open(const char *, int, ...);
